@@ -60,6 +60,28 @@ def download_remote_file(ssh: paramiko.client, remote_file_path: str, local_dir_
         ssh.close()
 
 
+def create_remote_directory(sftp, remote_directory):
+    """
+    Creates Directories if doesn't exists
+    :param sftp:
+    :param remote_directory:
+    :return:
+    """
+    import os
+    if remote_directory == '/':
+        return
+    if remote_directory == '':
+        return
+    try:
+        sftp.chdir(remote_directory)
+    except IOError:
+        dirname, basename = os.path.split(remote_directory.rstrip('/'))
+        create_remote_directory(sftp, dirname)
+        sftp.mkdir(basename)
+        sftp.chdir(basename)
+        return True
+
+
 def upload_local_file(ssh: paramiko.client, upload_dir_path: str, local_file_path: str, propagate_exceptions=False,
                       connection_close=True):
     """
@@ -78,10 +100,11 @@ def upload_local_file(ssh: paramiko.client, upload_dir_path: str, local_file_pat
     try:
         sftp = ssh.open_sftp()
         file_name = local_file_path.split('/')[-1]
+        create_remote_directory(sftp, upload_dir_path)
         remote_file_path = os.path.join(upload_dir_path, file_name)
         sftp.put(local_file_path, remote_file_path)
         return True
-    except (paramiko.SSHException, paramiko.SFTPError) as exception:
+    except (paramiko.SSHException, paramiko.SFTPError, IOError) as exception:
         logger.warning(exception)
         if propagate_exceptions:
             raise exception
